@@ -1,11 +1,12 @@
 """
 
 """
-__version__ = "0.15.0"
+__version__ = "1.0.0"
 
 from .core import Params, ParamsType, MetricType, Meter, Record, TrainStage, BaseParams
+from .proc import glob
 
 from .data import DataLoader, DataModule, DatasetBuilder, LumoDataLoader, CollateBase, DataLoaderSide
-from .exp import SimpleExperiment, Experiment
+from .exp import SimpleExperiment, Experiment, Metric, Watcher, C
 from .trainer import Trainer, TrainerParams, callbacks, RndManager
 from .utils import Logger
